@@ -1,4 +1,5 @@
 import asyncio
+import os
 import signal
 import sys
 from functools import partial
@@ -32,12 +33,17 @@ def main(ctx):
 @main.command()
 @click.option('--show-config', '-C', is_flag=True)
 def run(show_config: bool):
+    if sys.platform == 'win32':
+        os.environ['QT_QUICK_CONTROLS_STYLE'] = 'Universal'
+    elif sys.platform == 'darwin':
+        os.environ['QT_QUICK_CONTROLS_STYLE'] = 'macOS'
+
     from PyQt5.QtWidgets import QApplication
     from qasync import QEventLoop
     from fastocr.i18n import Translation
     from fastocr.tray import AppTray
 
-    if sys.platform not in ['win32', 'darwin', 'cygwin'] and instance_already_running():
+    if instance_already_running():
         AppLogger().info('only one instance running allowed')
         sys.exit(1)
 
@@ -50,8 +56,10 @@ def run(show_config: bool):
     loop = QEventLoop(app)
     asyncio.set_event_loop(loop)
     loop = asyncio.get_event_loop()
-    for s in [signal.SIGINT, signal.SIGTERM]:
-        loop.add_signal_handler(s, partial(quit_application, s))
+    if sys.platform != 'win32':
+        # add_signal_handler is not available on Windows
+        for s in [signal.SIGINT, signal.SIGTERM]:
+            loop.add_signal_handler(s, partial(quit_application, s))
     if DesktopInfo.dbus_supported():
         from fastocr.bus import app_dbus
         app_dbus.tray = AppTray(bus=app_dbus)
