@@ -1,6 +1,7 @@
 import asyncio
 import os
 import sys
+import tempfile
 
 
 class Singleton(type):
@@ -61,7 +62,8 @@ class DesktopInfo:
         if sys.platform == 'darwin':
             # macOS darkmode
             loop = asyncio.get_event_loop()
-            out, _, __ = loop.run_until_complete(run_command('defaults', 'read', '-g', 'AppleInterfaceStyle', allow_fail=True))
+            out, _, __ = loop.run_until_complete(
+                run_command('defaults', 'read', '-g', 'AppleInterfaceStyle', allow_fail=True))
             if out.strip().lower() == 'dark':
                 return True
             else:
@@ -115,7 +117,9 @@ async def check_exists(command):
 async def run_command(*args, allow_fail=False):
     process = await asyncio.create_subprocess_exec(
         *args,
-        stderr=asyncio.subprocess.PIPE, stdout=asyncio.subprocess.PIPE)
+        stderr=asyncio.subprocess.PIPE,
+        stdout=asyncio.subprocess.PIPE
+    )
     stdout, stderr = await process.communicate()
     if not allow_fail and process.returncode != 0:
         raise Exception(stderr.decode().strip())
@@ -126,7 +130,7 @@ async def open_in_default(filename):
     if sys.platform == 'darwin':
         await run_command('open', filename)
     if sys.platform == 'win32':
-        await run_command('start', filename)
+        os.startfile(filename)
     if sys.platform == 'linux':
         await run_command('xdg-open', filename)
 
@@ -136,14 +140,28 @@ def instance_already_running(label="default"):
     Detect if an an instance with the label is already running, globally
     at the operating system level.
     """
-    import fcntl
-    lock_file_pointer = os.open(f"/tmp/fastocr_{label}.lock", os.O_WRONLY | os.O_CREAT)
+    already_running = False
 
-    try:
-        fcntl.lockf(lock_file_pointer, fcntl.LOCK_EX | fcntl.LOCK_NB)
-        already_running = False
-    except IOError:
-        already_running = True
+    if sys.platform == 'win32':
+        tempdir = tempfile.gettempdir()
+        lockfile = os.sep.join([tempdir, f'fastocr_{label}.lock'])
+
+        try:
+            if os.path.exists(lockfile):
+                os.unlink(lockfile)
+            os.open(lockfile, os.O_CREAT | os.O_EXCL | os.O_RDWR)
+        except EnvironmentError as err:
+            if err.errno == 13:
+                already_running = True
+            else:
+                raise
+    else:
+        import fcntl
+        lock_file_pointer = os.open(f'/tmp/fastocr_{label}.lock', os.O_WRONLY | os.O_CREAT)
+        try:
+            fcntl.lockf(lock_file_pointer, fcntl.LOCK_EX | fcntl.LOCK_NB)
+        except IOError:
+            already_running = True
 
     return already_running
 
